/*********************************************************************************
 * A VERY SMALL LIBRARY TO MAKE GPIO OPERATIONS A LITTLE EASIER.                 *
 *********************************************************************************/

// IF THE delay() FUCNTION WILL BE USED, YOU MUST CALL SysTick_Config(SystemCoreClock / 1000000);
// BEFORE THE FIRST USE OF delay() OR ELSE AN INFINITE LOOP WILL OCCUR.

#include "simple_gpio.h"

volatile uint32_t micros = 0;

void SysTick_Handler() {
	micros++;
}

void EnablePin(enum GPIO_PIN pin) {
	// Enable GPIOx port clock, and set pin type as output
	
	char port = pin / 16;
	if(port == 0) { // port A
		RCC->AHB1ENR |= RCC_AHB1ENR_GPIOAEN;
		GPIOA->MODER |= (1 << (2*(pin % 16)));
	} else if(port == 1) { // port B
		RCC->AHB1ENR |= RCC_AHB1ENR_GPIOBEN;
		GPIOB->MODER |= (1 << (2*(pin % 16)));
	} else if(port == 2) { // port C
		RCC->AHB1ENR |= RCC_AHB1ENR_GPIOCEN;
		GPIOC->MODER |= (1 << (2*(pin % 16)));
	} else if(port == 3) { // port D
		RCC->AHB1ENR |= RCC_AHB1ENR_GPIODEN;
		GPIOD->MODER |= (1 << (2*(pin % 16)));
	} else if(port == 4) { // port E
		RCC->AHB1ENR |= RCC_AHB1ENR_GPIOEEN;
		GPIOE->MODER |= (1 << (2*(pin % 16)));
	}
}

void SetPin(enum GPIO_PIN pin) {
	// Change pin state to high

	char port = pin / 16;
	if(port == 0) { // port A
		GPIOA->BSRRL = (1 << (pin % 16));
	} else if(port == 1) { // port B
		GPIOB->BSRRL = (1 << (pin % 16));
	} else if(port == 2) { // port C
		GPIOC->BSRRL = (1 << (pin % 16));
	} else if(port == 3) { // port D
		GPIOD->BSRRL = (1 << (pin % 16));
	} else if(port == 4) { // port E
		GPIOE->BSRRL = (1 << (pin % 16));
	}
}

void ClearPin(enum GPIO_PIN pin) {
	// Change pin state to low

	char port = pin / 16;
	if(port == 0) { // port A
		GPIOA->BSRRH = (1 << (pin % 16));
	} else if(port == 1) { // port B
		GPIOB->BSRRH = (1 << (pin % 16));
	} else if(port == 2) { // port C
		GPIOC->BSRRH = (1 << (pin % 16));
	} else if(port == 3) { // port D
		GPIOD->BSRRH = (1 << (pin % 16));
	} else if(port == 4) { // port E
		GPIOE->BSRRH = (1 << (pin % 16));
	}
}

void delay(unsigned long duration) {
	// Wait for the specified number of microseconds
	
	unsigned long startTime = micros;
	while(startTime + duration > micros);
}
